#!/usr/bin/perl -w

use strict;
use Test::Harness;
runtests(qw(scripts/test_date-holidays_modules.t));
